pilas.actores.menu.Menu

Package pilas :: Package actores :: Module menu :: Class Menu |
[hide private]
[frames] | no frames]

# Class Menu

source code

                   object --+
                            |
    estudiante.Estudiante --+
                            |
                  actor.Actor --+
                                |
                               Menu

Un actor que puede mostrar una lista de opciones a seleccionar.

Instance Methods | [hide private]
__init__(self, opciones, x=0, y=0, fuente=None) Inicializa el menú. | source code
activar(self) Se ejecuta para activar el comportamiento del menú. | source code
desactivar(self) Deshabilita toda la funcionalidad del menú. | source code
crear_texto_de_las_opciones(self, opciones, fuente) Genera un actor por cada opcion del menu. | source code
seleccionar_primer_opcion(self) Destaca la primer opción del menú. | source code
_verificar_opciones(self, opciones) Se asegura de que la lista este bien definida. | source code
actualizar(self) Se ejecuta de manera periodica. | source code
seleccionar_opcion_actual(self) Se ejecuta para activar y lanzar el item actual. | source code
mover_cursor(self, delta) Realiza un movimiento del cursor que selecciona opciones. | source code
__setattr__(self, atributo, valor) x.__setattr__('name', value) <==> x.name = value | source code
cuando_mueve_el_mouse(self, evento) Permite cambiar la opcion actual moviendo el mouse. | source code
_deshabilitar_opcion_actual(self) Le quita el foco o resaltado a la opción del menú actual. | source code
cuando_hace_click_con_el_mouse(self, evento) Se ejecuta cuando se hace click con el mouse. | source code
Inherited from `actor.Actor`: `__cmp__`, `__mul__`, `__str__`, `actor_mas_cercano`, `anexar`, `colisiona_con`, `colisiona_con_un_punto`, `decir`, `definir_centro`, `definir_color`, `definir_escala`, `definir_imagen`, `definir_posicion`, `definir_rotacion`, `definir_transparencia`, `destruir`, `dibujar`, `distancia_al_punto`, `distancia_con`, `duplicar`, `eliminar`, `es_fondo`, `esta_fuera_de_la_pantalla`, `get_abajo`, `get_arriba`, `get_derecha`, `get_espejado`, `get_fijo`, `get_imagen`, `get_izquierda`, `get_rotation`, `get_scale`, `get_scale_x`, `get_scale_y`, `get_transparencia`, `get_vx`, `get_vy`, `get_x`, `get_y`, `get_z`, `imitar`, `obtener_alto`, `obtener_ancho`, `obtener_centro`, `obtener_escala`, `obtener_imagen`, `obtener_posicion`, `obtener_rotacion`, `pre_actualizar`, `set_abajo`, `set_arriba`, `set_derecha`, `set_espejado`, `set_fijo`, `set_imagen`, `set_izquierda`, `set_rotation`, `set_scale`, `set_scale_x`, `set_scale_y`, `set_transparencia`, `set_x`, `set_y`, `set_z` Inherited from `actor.Actor` (private): `_eliminar_anexados`, `_interpretar_y_convertir_posicion` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__sizeof__`, `__subclasshook__` Inherited from `estudiante.Estudiante`: `actualizar_comportamientos`, `actualizar_habilidades`, `agregar_habilidad`, `aprender`, `eliminar_comportamientos`, `eliminar_habilidad`, `eliminar_habilidades`, `hacer`, `hacer_luego`, `obtener_habilidad`, `tiene_comportamiento`, `tiene_habilidad` Inherited from `estudiante.Estudiante` (private): `_adoptar_el_siguiente_comportamiento`

Properties | [hide private]
Inherited from `actor.Actor`: `abajo`, `alto`, `ancho`, `arriba`, `centro`, `derecha`, `escala`, `escala_x`, `escala_y`, `espejado`, `fijo`, `imagen`, `izquierda`, `rotacion`, `transparencia`, `vx`, `vy`, `x`, `y`, `z` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, opciones, x=0, y=0, fuente=None) (Constructor) | source code
Inicializa el menú. :param opciones: Tupla con al menos dos elementos obligatorios (:texto:, :funcion:) y :argumentos: opcionales :param x: Posicion en el eje x :param y: Posicion en el eje y Overrides: estudiante.Estudiante.__init__

### crear_texto_de_las_opciones(self, opciones, fuente) | source code
Genera un actor por cada opcion del menu. :param opciones: Una lista con todas las opciones que tendrá el menú.

### _verificar_opciones(self, opciones) | source code
Se asegura de que la lista este bien definida. :param opciones: La lista de opciones a inspeccionar.

### actualizar(self) | source code
Se ejecuta de manera periodica. Overrides: actor.Actor.actualizar

### mover_cursor(self, delta) | source code
Realiza un movimiento del cursor que selecciona opciones. :param delta: El movimiento a realizar (+1 es avanzar y -1 retroceder).

### __setattr__(self, atributo, valor) | source code
x.__setattr__('name', value) <==> x.name = value Overrides: object.__setattr__ (inherited documentation)

### cuando_mueve_el_mouse(self, evento) | source code
Permite cambiar la opcion actual moviendo el mouse. Retorna True si el mouse esta sobre alguna opcion. :param evento: El evento que representa el movimiento del mouse.

### cuando_hace_click_con_el_mouse(self, evento) | source code
Se ejecuta cuando se hace click con el mouse. :param evento: objeto que representa el evento click de mouse.